@@ -33,12 +33,13 @@ class perc(PathExtractorUnit):
     """
     Extract PE file resources.
     """
-    def __init__(self, *paths, list=False, join=False, regex=False, path=b'path'):
+    def __init__(self, *paths, list=False, join_path=False, drop_path=False, regex=False, path=b'path'):
         def fixpath(p: str):
             if regex or not p.isidentifier():
                 return p
             return re.compile(FR'^.*?{re.escape(p)}.*$')
-        super().__init__(*(fixpath(p) for p in paths), list=list, join=join, path=path)
+        super().__init__(*(fixpath(p) for p in paths),
+            list=list, join_path=join_path, drop_path=drop_path, path=path)
 
     def _search(self, pe, directory, level=0, *parts):
         if level >= 3:
